@@ -12,21 +12,29 @@ class ErrorCodes(object):
 
     class Address(object):
         CannotBeBlank = "81801"
+        CompanyIsInvalid = "91821"
         CompanyIsTooLong = "81802"
         CountryCodeAlpha2IsNotAccepted = "91814"
         CountryCodeAlpha3IsNotAccepted = "91816"
         CountryCodeNumericIsNotAccepted = "91817"
         CountryNameIsNotAccepted = "91803"
         ExtedAddressIsTooLong = "81804" # Deprecated
+        ExtendedAddressIsInvalid = "91823"
         ExtendedAddressIsTooLong = "81804"
+        FirstNameIsInvalid = "91819"
         FirstNameIsTooLong = "81805"
         InconsistentCountry = "91815"
+        LastNameIsInvalid = "91820"
         LastNameIsTooLong = "81806"
+        LocalityIsInvalid = "91824"
         LocalityIsTooLong = "81807"
         PostalCodeInvalidCharacters = "81813"
+        PostalCodeIsInvalid = "91826"
         PostalCodeIsRequired = "81808"
         PostalCodeIsTooLong = "81809"
+        RegionIsInvalid = "91825"
         RegionIsTooLong = "81810"
+        StreetAddressIsInvalid = "91822"
         StreetAddressIsRequired = "81811"
         StreetAddressIsTooLong = "81812"
         TooManyAddressesPerCustomer = "91818"
@@ -48,15 +56,18 @@ class ErrorCodes(object):
         ExpirationDateYearIsInvalid = "81711"
         ExpirationMonthIsInvalid = "81712"
         ExpirationYearIsInvalid = "81713"
-        NumberHasInvalidLength = "81716"
+        InvalidVenmoSDKPaymentMethodCode = "91727"
+        NumberHasInvalidLength = NumberLengthIsInvalid = "81716"
         NumberIsInvalid = "81715"
         NumberIsRequired = "81714"
         NumberMustBeTestNumber = "81717"
-        TokenInvalid = "91718"
+        PaymentMethodConflict = "81725"
+        TokenInvalid = TokenFormatIsInvalid = "91718"
         TokenIsInUse = "91719"
         TokenIsNotAllowed = "91721"
         TokenIsRequired = "91722"
         TokenIsTooLong = "91720"
+        VenmoSDKPaymentMethodCodeCardTypeIsNotAccepted = "91726"
 
         class Options(object):
             UpdateExistingTokenIsInvalid = "91723"
@@ -66,7 +77,7 @@ class ErrorCodes(object):
         CompanyIsTooLong = "81601"
         CustomFieldIsInvalid = "91602"
         CustomFieldIsTooLong = "81603"
-        EmailIsInvalid = "81604"
+        EmailIsInvalid = EmailFormatIsInvalid = "81604"
         EmailIsRequired = "81606"
         EmailIsTooLong = "81605"
         FaxIsTooLong = "81607"
@@ -79,13 +90,17 @@ class ErrorCodes(object):
         IdIsTooLong = "91612"
         LastNameIsTooLong = "81613"
         PhoneIsTooLong = "81614"
-        WebsiteIsInvalid = "81616"
+        WebsiteIsInvalid = WebsiteFormatIsInvalid = "81616"
         WebsiteIsTooLong = "81615"
 
     class Descriptor(object):
+        DynamicDescriptorsDisabled = "92203"
+        InternationalNameFormatIsInvalid = "92204"
+        InternationalPhoneFormatIsInvalid = "92205"
         NameFormatIsInvalid = "92201"
         PhoneFormatIsInvalid = "92202"
 
+
     class SettlementBatchSummary(object):
         CustomFieldIsInvalid = "82303"
         SettlementDateIsInvalid = "82302"
@@ -140,6 +155,7 @@ class ErrorCodes(object):
             InconsistentNumberOfBillingCycles = "92018"
             InheritedFromIdIsInvalid = "92013"
             InheritedFromIdIsRequired = "92014"
+            Missing = "92024"
             NumberOfBillingCyclesCannotBeBlank = "92017"
             NumberOfBillingCyclesIsInvalid = "92005"
             NumberOfBillingCyclesMustBeGreaterThanZero = "92019"
@@ -149,7 +165,7 @@ class ErrorCodes(object):
 
     class Transaction(object):
         AmountCannotBeNegative = "81501"
-        AmountIsInvalid = "81503"
+        AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
         AmountMustBeGreaterThanZero = "81531"
@@ -164,6 +180,7 @@ class ErrorCodes(object):
         CannotRefundWithSuspendedMerchantAccount = "91538"
         CannotSubmitForSettlement = "91507"
         ChannelIsTooLong = "91550"
+        ChannelIsTooLong = "91550"
         CreditCardIsRequired = "91508"
         CustomFieldIsInvalid = "91526"
         CustomFieldIsTooLong = "81527"
@@ -178,6 +195,7 @@ class ErrorCodes(object):
         MerchantAccountNameIsInvalid = "91513" # Deprecated
         OrderIdIsTooLong = "91501"
         PaymentMethodConflict = "91515"
+        PaymentMethodConflictWithVenmoSDK = "91549"
         PaymentMethodDoesNotBelongToCustomer = "91516"
         PaymentMethodDoesNotBelongToSubscription = "91527"
         PaymentMethodTokenCardTypeIsNotAccepted = "91517"
@@ -186,8 +204,8 @@ class ErrorCodes(object):
         ProcessorAuthorizationCodeIsInvalid = "81520"
         ProcessorDoesNotSupportCredits = "91546"
         ProcessorDoesNotSupportVoiceAuthorizations = "91545"
-        PurchaseOrderNumberIsTooLong = "91537"
         PurchaseOrderNumberIsInvalid = "91548"
+        PurchaseOrderNumberIsTooLong = "91537"
         RefundAmountIsTooLarge = "91521"
         SettlementAmountIsTooLarge = "91522"
         SubscriptionDoesNotBelongToCustomer = "91529"
